/*
******************************************************************************
* Date: 24th Apr 2008
* Microchip Graphics Library modified for C18.
* Only font Flash is supported for now. NO bitmap function has been ported yet.
* This program demonstrates user interaction by 5-way joystick.
* Try the joystick to see what happens to color LCD
* 
* FileName:        JoystickMain.c
* Dependencies:	   includes.h
* Hardware:		   PIC18LF4550-Eval-Rev4a + TY240-240320-BO Rev 1B
* Processor:       PIC18LF4550 at Vdd=3.3V
* Compiler:        MPLAB C18 student version under MPLAB v8.02
* Programmer : 	   John Leung (www.TechToys.com.hk)
* Note:		       Please refer to the original Software License Agreement
*				   from Microchip for details concerning Copyright
******************************************************************************
*/

/*
******************************************************************************
* Date: 30th Apr 2008
* Joystick demo port for TY320T 3.2" TFT LCD
******************************************************************************
*/

#include "includes.h"
/*
********************************************************************************************************************
*												Pragma Section
*
* Configuration bits under MPLAB v7.60 subject to changes on every little change on project settings.
* So #pragma config statments used for configuration bits instead of using Configuration bits tab in MPLAB
* Refer to pdf document "mcc18\doc\MPLAB-C18-Addendum.pdf" under mcc18 installation directory for config
* variables available
********************************************************************************************************************
*/
#pragma config PLLDIV = 5			// 20Mhz crystal input, the PLL divider has to be 5 for a fixed 4MHz input to PLL
#pragma config FOSC   = HSPLL_HS	// HS oscillator, PLL sourced
#pragma config CPUDIV = OSC1_PLL2	// Since it is now PLL sourced, the CPU clock = 96MHz PLL/2 => 48MHz
									// From specification the max. clock is around 20MHz for Vdd=3.3V
									// This scenario is like a bit over-clocking the microcontroller!
#pragma config PWRT   = ON			// PowerUp timer ON
#pragma config WDT    = OFF			// watchdog timer off
#pragma config LVP    = OFF			// low level voltage progamming OFF
#pragma config BOR    = OFF			// brown out detect off
#pragma config DEBUG  = ON			// Debug ON
#pragma config PBADEN = OFF 		// PORTB<4:0> as digital IO on reset
#pragma config STVREN = ON  		// Stack overflow reset ON
#pragma config VREGEN = OFF			// Disable internal 3.3V regulator!

///////////////////////////////// FONTS ///////////////////////////////////////
extern FONT_FLASH Font25;

///////////////////////////////// FONTS ///////////////////////////////////////

char start[] = "Please try 5-way key";
char upkey[] = "Hey, you've clicked UP key";
char rtkey[] = "Well, it is a right key";
char dnkey[] = "Let force be with you";


void main(void){

char keyCode;
SHORT width, height;
SHORT counter;
const SHORT polyPoints[] = {
160,60,
240,120,
160,180,
80,120,
160,60,
};

	xKeyInit();									//initialize the keypad module before using it
    InitGraph();								//initialize the graphics library

	SetFont(&Font25);							//display welcome message here
    SetColor(WHITE);
    width = GetTextWidth(&start[0],&Font25);
    height = GetTextHeight(&Font25);
    OutTextXY( (GetMaxX()-width)>>1,(GetMaxY()-height)>>1,&start[0]);
	
	for(;;){
			DelayMs(xKEY_SCAN_TASK_DLY);	//debounce the keys
			xKeyScanTask();
			if(xKeyHit()){
				keyCode = xKeyGetKey();
				switch(keyCode)
				{
					case xKEY_UP_FLAG:
							SetColor(BLACK);
							ClearDevice();
	        				SetColor(BRIGHTBLUE);
        					FillCircle(GetMaxX()>>1,GetMaxY()>>1,60);
        					SetColor(BRIGHTGREEN);
        					FillCircle(GetMaxX()>>1,GetMaxY()>>1,40);
        					SetColor(BRIGHTRED);
        					FillCircle(GetMaxX()>>1,GetMaxY()>>1,20);
							//SetFont(&Font25);
        					SetColor(BRIGHTGREEN);
        					width = GetTextWidth(&upkey[0],&Font25);
        					height = GetTextHeight(&Font25);
        					OutTextXY( (GetMaxX()-width)>>1,250,&upkey[0]);
							break;
					case xKEY_DN_FLAG:
							SetColor(LIGHTMAGENTA);
							ClearDevice();
        					Arc((GetMaxX()>>1),(GetMaxY()>>1)-50,(GetMaxX()>>1),(GetMaxY()>>1)+50,50,60,0x11);
					        SetColor(BRIGHTGREEN);
   						    Arc((GetMaxX()>>1),(GetMaxY()>>1)-50,(GetMaxX()>>1),(GetMaxY()>>1)+50,50,60,0x22);
  						    SetColor(BRIGHTRED);
        					Arc((GetMaxX()>>1),(GetMaxY()>>1)-50,(GetMaxX()>>1),(GetMaxY()>>1)+50,50,60,0x44);
        					SetColor(BRIGHTYELLOW);
        					Arc((GetMaxX()>>1),(GetMaxY()>>1)-50,(GetMaxX()>>1),(GetMaxY()>>1)+50,50,60,0x88);
							//SetFont(&Font25);
        					SetColor(BLACK);
        					width = GetTextWidth(&dnkey[0],&Font25);
        					height = GetTextHeight(&Font25);
        					OutTextXY( (GetMaxX()-width)>>1,280,&dnkey[0]);						
							break;
					case xKEY_LT_FLAG:
							SetColor(BRIGHTBLUE);
							ClearDevice();
							break;
					case xKEY_RT_FLAG:
							SetColor(BRIGHTBLUE);
							ClearDevice();
        					Bevel((GetMaxX()>>1)-60,(GetMaxY()>>1)-60,(GetMaxX()>>1)+60,(GetMaxY()>>1)+60,30);
        					SetColor(BRIGHTGREEN);
        					Bevel((GetMaxX()>>1)-40,(GetMaxY()>>1)-40,(GetMaxX()>>1)+40,(GetMaxY()>>1)+40,30);
        					SetColor(BRIGHTRED);
        					Bevel((GetMaxX()>>1)-20,(GetMaxY()>>1)-20,(GetMaxX()>>1)+20,(GetMaxY()>>1)+20,30);
							//SetFont(&Font25);
        					SetColor(BLACK);
        					width = GetTextWidth(&rtkey[0],&Font25);
        					height = GetTextHeight(&Font25);
        					OutTextXY( (GetMaxX()-width)>>1,250,&rtkey[0]);
							break;
					case xKEY_CTR_FLAG:							
							SetColor(BRIGHTMAGENTA);
							ClearDevice();
							break;
				}
			}
	}

}